@@ -14,7 +14,7 @@
 from typing import Any
 
 from pytorch_lightning.callbacks.callback import Callback as NewCallback
-from pytorch_lightning.utilities import rank_zero_deprecation
+from pytorch_lightning.utilities.rank_zero import rank_zero_deprecation
 
 
 class Callback(NewCallback):
